==> matterhorn-50200.12.0.tar.gz: matterhorn-50200.12.0/docs/commands.md <==
# Commands

| Command | Description |
| ------- | ----------- |
| `/add-user` | Search for a user to add to the current channel |
| `/add-user <@user>` | Add a user to the current channel |
| `/create-channel <channel name>` | Create a new public channel |
| `/create-private-channel <channel name>` | Create a new private channel |
| `/delete-channel` | Delete the current channel |
| `/flags` | Open a window of your flagged posts |
| `/focus <~channel>` | Focus on a channel or user |
| `/focus` | Select from available channels |
| `/group-msg <@user [@user ...]>` | Create a group chat |
| `/help` | Show the main help screen |
| `/help <topic>` | Show help about a particular topic |
| `/hide` | Hide the current DM or group channel from the channel list |
| `/join` | Find a channel to join |
| `/join <~channel>` | Join the specified channel |
| `/leave` | Leave a normal channel or hide a DM channel |
| `/left` | Focus on the previous channel |
| `/log-mark <message>` | Add a custom marker message to the Matterhorn debug log |
| `/log-snapshot <path>` | Dump the current debug log buffer to the specified path |
| `/log-start <path>` | Begin logging debug information to the specified path |
| `/log-status` | Show current debug logging status |
| `/log-stop` | Stop logging |
| `/members` | Show the current channel's members |
| `/message-preview` | Toggle preview of the current message |
| `/move-team-left` | Move the currently-selected team to the left in the team list |
| `/move-team-right` | Move the currently-selected team to the right in the team list |
| `/msg` | Search for a user to enter a private chat |
| `/msg <@user>` | Chat with the specified user |
| `/msg <@user> <message or command>` | Go to a user's channel and send the specified message or command |
| `/notify-prefs` | Edit the current channel's notification preferences |
| `/pinned-posts` | Open a window of this channel's pinned posts |
| `/quit` | Exit Matterhorn |
| `/reconnect` | Force a reconnection attempt to the server |
| `/remove-user <@user>` | Remove a user from the current channel |
| `/rename-channel-url <channel name>` | Rename the current channel's URL name |
| `/right` | Focus on the next channel |
| `/search <terms>` | Search for posts with given terms |
| `/sh` | List the available shell scripts |
| `/sh <script> <message>` | Run a prewritten shell script |
| `/shortcuts` | Show keyboard shortcuts |
| `/theme` | List the available themes |
| `/theme <theme>` | Set the color theme |
| `/toggle-channel-list` | Toggle channel list visibility |
| `/toggle-expanded-topics` | Toggle expanded channel topics |
| `/toggle-message-timestamps` | Toggle message timestamps |
| `/topic` | Set the current channel's topic (header) interactively |
| `/topic <topic>` | Set the current channel's topic (header) |
| `/user` | Show users to initiate a private DM chat channel |
| `/username-attribute <@user>` | Display the attribute used to color the specified username |

==> matterhorn-50200.13.0.tar.gz: matterhorn-50200.13.0/docs/commands.md <==
# Commands

| Command | Description |
| ------- | ----------- |
| `/add-user` | Search for a user to add to the current channel |
| `/add-user <@user>` | Add a user to the current channel |
| `/attach <path>` | Attach a given file without browsing |
| `/create-channel <channel name>` | Create a new public channel |
| `/create-private-channel <channel name>` | Create a new private channel |
| `/delete-channel` | Delete the current channel |
| `/flags` | Open a window of your flagged posts |
| `/focus <~channel>` | Focus on a channel or user |
| `/focus` | Select from available channels |
| `/group-create <@user [@user ...]>` | Create a group chat |
| `/help` | Show the main help screen |
| `/help <topic>` | Show help about a particular topic |
| `/hide` | Hide the current DM or group channel from the channel list |
| `/join` | Find a channel to join |
| `/join <~channel>` | Join the specified channel |
| `/leave` | Leave a normal channel or hide a DM channel |
| `/left` | Focus on the previous channel |
| `/log-mark <message>` | Add a custom marker message to the Matterhorn debug log |
| `/log-snapshot <path>` | Dump the current debug log buffer to the specified path |
| `/log-start <path>` | Begin logging debug information to the specified path |
| `/log-status` | Show current debug logging status |
| `/log-stop` | Stop logging |
| `/members` | Show the current channel's members |
| `/message-preview` | Toggle preview of the current message |
| `/move-team-left` | Move the currently-selected team to the left in the team list |
| `/move-team-right` | Move the currently-selected team to the right in the team list |
| `/msg` | Search for a user to enter a private chat |
| `/msg <@user>` | Chat with the specified user |
| `/msg <@user> <message or command>` | Go to a user's channel and send the specified message or command |
| `/notify-prefs` | Edit the current channel's notification preferences |
| `/pinned-posts` | Open a window of this channel's pinned posts |
| `/quit` | Exit Matterhorn |
| `/reconnect` | Force a reconnection attempt to the server |
| `/remove <@user>` | Remove a user from the current channel |
| `/rename-channel-url <channel name>` | Rename the current channel's URL name |
| `/right` | Focus on the next channel |
| `/search <terms>` | Search for posts with given terms |
| `/sh` | List the available shell scripts |
| `/sh <script> <message>` | Run a prewritten shell script |
| `/shortcuts` | Show keyboard shortcuts |
| `/theme` | List the available themes |
| `/theme <theme>` | Set the color theme |
| `/toggle-channel-list` | Toggle channel list visibility |
| `/toggle-expanded-topics` | Toggle expanded channel topics |
| `/toggle-favorite` | Toggle the favorite status of the current channel |
| `/toggle-message-timestamps` | Toggle message timestamps |
| `/topic` | Set the current channel's topic (header) interactively |
| `/topic <topic>` | Set the current channel's topic (header) |
| `/user` | Show users to initiate a private DM chat channel |
| `/username-attribute <@user>` | Display the attribute used to color the specified username |
